## ---- include = FALSE---------------------------------------------------------
knitr::opts_chunk$set(
        collapse = TRUE,
        comment = "#>"
)
if (!require("png")) {
  install.packages("png",repos = "http://cran.us.r-project.org")
  library("png")
}


## -----------------------------------------------------------------------------
library(lczexplore)
dirPath<-paste0(system.file("extdata",package="lczexplore"),"/")
dirPathOSM<-paste0(dirPath,"osm/2022/Redon")
dirPathBDT<-paste0(dirPath,"bdtopo_2_2/Redon")
redonOSM<-importLCZvect(dirPath=dirPathOSM,file="rsu_lcz.geojson",column = "LCZ_PRIMARY")
redonBDT<-importLCZvect(dirPath=dirPathBDT,file="rsu_lcz.geojson",column = "LCZ_PRIMARY")
#

## ---- fig.dim = c(8, 6)-------------------------------------------------------

comparison<-compareLCZ(sf1=redonBDT,column1="LCZ_PRIMARY", wf1="BD TOPO v2.2",
                        sf2=redonOSM,column2="LCZ_PRIMARY",wf2="Open Street Map", ref=1,
                        repr="standard",exwrite=F,location="Redon",saveG="")
comparison$pseudoK

## ---- fig.dim = c(8, 6)-------------------------------------------------------
redonOSMgrouped<-groupLCZ(redonOSM,column="LCZ_PRIMARY",
                           urban=c("1","2","3","4","5","6","7","8","9"),
                           industry="10",
                           vegetation=c("101","102","103","104"),
                           impervious="105",pervious="106",water="107", 
                           colors=c("red","black","green","grey","burlywood","blue"))

levCol(sf=redonOSMgrouped,column="grouped",LCZlevels = c("urban","industry","vegetation","impervious","pervious","water"),
       colors=c("red","black","green","grey","burlywood","blue"))

map1<-showLCZ(redonOSMgrouped, column="grouped",repr="alter",wf="OSM",
        LCZlevels = c("urban","industry","vegetation","impervious","pervious","water"),
        colors=c("red","black","green","grey","burlywood","blue"))


## ---- fig.dim = c(8, 6)-------------------------------------------------------

redonBDTgrouped<-groupLCZ(redonBDT,column="LCZ_PRIMARY",
                           urban=c("1","2","3","4","5","6","7","8","9"),
                           industry="10",
                           vegetation=c("101","102","103","104"),
                           impervious="105",pervious="106",water="107",
                           colors=c("red","black","green","grey","burlywood","blue"))

comparisonGrouped<-compareLCZ(sf1=redonOSMgrouped,column1="grouped",
sf2=redonBDTgrouped, column2="grouped",
repr="alter",
levels=c("urban","industry","vegetation","impervious","pervious","water"),
colors=c("red","black","green","grey","burlywood","blue"))

## ---- fig.dim = c(8, 6), echo = TRUE------------------------------------------
levCol(sf=redonOSMgrouped,column="grouped",
       levels=c("urban","industry","vegetation","impervious","pervious","water"))

compareLCZ(sf1=redonOSMgrouped,column1="grouped",
sf2=redonBDTgrouped, column2="grouped",
repr="alter",
levels=c("urban","industry","vegetation","impervious","pervious","water")
)

## ---- fig.dim = c(8, 6), echo = TRUE------------------------------------------
utrfRedonBDT<-importQualVar(dirPath=paste0(
  system.file("extdata", package = "lczexplore"), "/bdtopo_2_2/Redon"),
                            file="rsu_utrf_area.geojson", column="TYPO_MAJ")
summary(utrfRedonBDT)
summary(utrfRedonBDT$TYPO_MAJ)

map3<-showLCZ(sf=utrfRedonBDT, column="TYPO_MAJ",repr="alter",
        title = " UTRF classification of the French city of Redon",
        colors=c("red","black","green","grey","burlywood","blue","orange","lightgreen","brown"))

## -----------------------------------------------------------------------------
levCol(sf=utrfRedonBDT, column="TYPO_MAJ",
        colors=c("red","black","green","grey","burlywood","blue","orange","lightgreen","brown"))

levCol(sf=utrfRedonBDT, column="TYPO_MAJ",
       colors=c("red","black","green","grey","burlywood","blue","orange","lightgreen","NOT_COLOR"))


## -----------------------------------------------------------------------------
levCol(sf=redonOSMgrouped,column="grouped",
       levels=c("urban","industry","vegetation","impervious","pervious"),
       colors=c("red","black","green","grey","burlywood")
)


## -----------------------------------------------------------------------------
levCol(sf=redonOSMgrouped,column="grouped",
       levels=c("urban","industry","vegetation","impervious","pervious","water"),
       colors=c("red","black","green","grey","burlywood")
)


## -----------------------------------------------------------------------------
levCol(sf=redonOSMgrouped,column="grouped",
           levels=c("urban","industry","vegetation","impervious","pervious"),
           colors=c("red","black","green","grey","burlywood","blue")
)

## ---- fig.dim = c(8, 6), echo = TRUE------------------------------------------

map4<-showLCZ(sf=redonBDT, column="LCZ_PRIMARY", repr="alter",
        urban=c("1","2","3","4","5","6","7","8","9"),
        industry="10",
        vegetation=c("101","102","103","104"),
        impervious="105",pervious="106",water="107",
        colors=c("red","black","green","grey","burlywood","blue"),tryGroup = TRUE)


compareLCZ(sf1=redonBDT, column1="LCZ_PRIMARY", 
    sf2=redonOSM, column2="LCZ_PRIMARY",
    repr="alter", ref=2, saveG="", exwrite=FALSE, location="Redon", plot=TRUE,
    urban=c("1","2","3","4","5","6","7","8","9"),
    industry="10",
    vegetation=c("101","102","103","104"),
    impervious="105",pervious="106",water="107",
    colors=c("red","black","green","grey","burlywood","blue"),tryGroup = TRUE)

