## ---- include = FALSE---------------------------------------------------------
knitr::opts_chunk$set(
        collapse = TRUE,
        comment = "#>"
)
if (!require("png")) {
  install.packages("png",repos = "http://cran.us.r-project.org")
  library("png")
}


## -----------------------------------------------------------------------------
library(ggplot2)
library(lczexplore)

## -----------------------------------------------------------------------------
dirPath<-paste0(system.file("extdata",package="lczexplore"),"/")
dirPathOSM<-paste0(dirPath,"osm/2022/Redon")
dirPathBDT<-paste0(dirPath,"bdtopo_2_2/Redon")
redonOSM<-importLCZvect(dirPath=dirPathOSM,file="rsu_lcz.geojson",column = "LCZ_PRIMARY")
redonBDT<-importLCZvect(dirPath=dirPathBDT,file="rsu_lcz.geojson",column = "LCZ_PRIMARY")
#

## ---- fig.dim = c(8, 6)-------------------------------------------------------
showLCZ(sf=redonOSM,wf="OSM",column="LCZ_PRIMARY",repr="standard",LCZlevels="",colors="")

## ---- fig.dim = c(8, 6), echo = FALSE-----------------------------------------
showLCZ(sf=redonOSM,wf="OSM",column="LCZ_PRIMARY",repr="standard",drop=TRUE)

## ---- fig.dim = c(8, 6)-------------------------------------------------------
# Choice of random colors from a palette
testCol <- palette.colors(n=17, palette="Polychrome 36")
showLCZ(sf=redonOSM,wf="OSM",column="LCZ_PRIMARY",repr="alter",colors=testCol, useStandCol = FALSE, drop=TRUE)


## ---- fig.dim = c(8, 6)-------------------------------------------------------

LCZlevels<-c(2, 3, 5, 6, 8, 9, 101, 102, 104, 105, 107)
couleurs<-c("red","brown1","orange","coral","grey","darkgreen","chartreuse4","springgreen3",
            "darkolivegreen","black","#6d67fd")
showLCZ(sf=redonOSM,wf="OSM",column="LCZ_PRIMARY",repr="alter",drop=TRUE,LCZlevels=LCZlevels,colors=couleurs)


## ---- fig.dim = c(8, 6)-------------------------------------------------------
redonOSMgrouped<-groupLCZ(redonOSM,column="LCZ_PRIMARY",
                           urban=c("1","2","3","4","5","6","7","8","9"),
                           industry="10",
                           vegetation=c("101","102","103","104"),
                           impervious="105",pervious="106",water="107",colors=c("red","black","green","grey","burlywood","blue"))
showLCZ(redonOSMgrouped, column="grouped",repr="alter",wf="OSM",
        LCZlevels = c("urban","industry","vegetation","impervious","pervious","water"),
        colors=c("red","black","green","grey","burlywood","blue"))


## ---- fig.dim = c(12,9 ), echo = TRUE, fig.show="hide"------------------------
comparison<-compareLCZ(sf1=redonBDT,column1="LCZ_PRIMARY", wf1="BD TOPO v2.2",
                        sf2=redonOSM,column2="LCZ_PRIMARY",wf2="Open Street Map", ref=1,
                        repr="standard",exwrite=F, location="Redon", saveG="comparison")

## ---- out.width = "680px"-----------------------------------------------------

knitr::include_graphics("comparison.png", error=FALSE)


## ---- echo = TRUE, fig.show="hide"--------------------------------------------
redonOSMgrouped<-groupLCZ(redonOSM,column="LCZ_PRIMARY",
                           urban=c("1","2","3","4","5","6","7","8","9"),
                           industry="10",
                           vegetation=c("101","102","103","104"),
                           impervious="105",pervious="106",water="107",colors=c("red","black","green","grey","burlywood","blue"))
redonBDTgrouped<-groupLCZ(redonBDT,column="LCZ_PRIMARY",
                           urban=c("1","2","3","4","5","6","7","8","9"),
                           industry="10",
                           vegetation=c("101","102","103","104"),
                           impervious="105",pervious="106",water="107",colors=c("red","black","green","grey","burlywood","blue"))
comparisonGrouped<-compareLCZ(sf1=redonOSMgrouped,column1="grouped",
           sf2=redonBDTgrouped, column2="grouped",
           repr="alter", 
           levels=c("urban","industry","vegetation","impervious","pervious","water"),
           colors=c("red","black","green","grey","burlywood","blue"), saveG="comparisonGrouped") 

## ---- out.width = "680px"-----------------------------------------------------

knitr::include_graphics("comparisonGrouped.png", error=FALSE)


## ---- out.width="70%", echo = TRUE, fig.show="hide"---------------------------
comparisonGrouped<-compareLCZ(sf1=redonBDT,column1="LCZ_PRIMARY", wf1="groupedBDT",
    sf2=redonOSM, column2="LCZ_PRIMARY", wf2="groupedOSM",
    repr="alter", ref=2, saveG="", exwrite=FALSE, location="Redon", plot=TRUE,
    urban=c("1","2","3","4","5","6","7","8","9"),
    industry="10",
    vegetation=c("101","102","103","104"),
    impervious="105",pervious="106",water="107",
    colors=c("red","black","green","grey","burlywood","blue"),tryGroup = TRUE)



## -----------------------------------------------------------------------------
comparison$percAgg
comparisonGrouped$areas

## -----------------------------------------------------------------------------
dirPath<-paste0(system.file("extdata",package="lczexplore"),"/")
dirPathOSM<-paste0(dirPath,"osm/2022/Redon")
dirPathBDT<-paste0(dirPath,"bdtopo_2_2/Redon")

redonOSM<-importLCZvect(dirPath=dirPathOSM,file="rsu_lcz.geojson",column = "LCZ_PRIMARY",geomID = "ID_RSU",confid="LCZ_UNIQUENESS_VALUE")

redonBDT<-importLCZvect(dirPath=dirPathBDT,file="rsu_lcz.geojson",column = "LCZ_PRIMARY",geomID = "ID_RSU",confid="LCZ_UNIQUENESS_VALUE")

redonCompare<-compareLCZ(sf1=redonBDT,wf1="bdt", geomID1 = "ID_RSU",column1 ="LCZ_PRIMARY",
                         confid1 = "LCZ_UNIQUENESS_VALUE",
                         sf2=redonOSM,wf2="osm",geomID2 = "ID_RSU",column2="LCZ_PRIMARY",confid2 ="LCZ_UNIQUENESS_VALUE",exwrite=FALSE,plot=FALSE)

## ---- fig.show="hide"---------------------------------------------------------
names(redonCompare$data)
confidRedon<-confidSensib(inputDf=redonCompare$data,filePath="", nPoints=10,
             wf1="bdtopo_2_2", wf2="osm",
             geomID1="ID_RSU", column1="LCZ_PRIMARY", confid1="LCZ_UNIQUENESS_VALUE",
             geomID2="ID_RSU.1",column2="LCZ_PRIMARY.1", confid2="LCZ_UNIQUENESS_VALUE.1",
             sep=";", repr="standard",
             plot=TRUE, saveG = ".")


## ---- out.width = "680px"-----------------------------------------------------

knitr::include_graphics("GeneralUniquenessSensib.png", error=FALSE)


## ---- out.width = "680px"-----------------------------------------------------

knitr::include_graphics("byLCZUniquenessSensib.png", error=FALSE)


