## ---- include = FALSE---------------------------------------------------------
knitr::opts_chunk$set(
        collapse = TRUE,
        comment = "#>"
)

if (!require("png")) {
  install.packages("png",repos = "http://cran.us.r-project.org")
  library("png")
}


## -----------------------------------------------------------------------------
library(lczexplore)

## -----------------------------------------------------------------------------
dirPath<-paste0(system.file("extdata",package="lczexplore"),"/")
dirPathOSM<-paste0(dirPath,"osm/2022/Redon")
dirPathBDT<-paste0(dirPath,"bdtopo_2_2/Redon")
redonOSM<-importLCZvect(dirPath=dirPathOSM,file="rsu_lcz.geojson",column = "LCZ_PRIMARY", verbose=FALSE)
redonBDT<-importLCZvect(dirPath=dirPathBDT,file="rsu_lcz.geojson",column = "LCZ_PRIMARY", verbose = FALSE)
#

## ---- echo=FALSE, fig.dim = c(8, 6)-------------------------------------------
map1<-showLCZ(sf=redonOSM, wf="OSM", column="LCZ_PRIMARY", repr="standard")

## ---- fig.dim = c(8, 6), echo = FALSE-----------------------------------------
map2<-showLCZ(sf=redonOSM,wf="OSM",column="LCZ_PRIMARY",repr="standard",drop=TRUE)

## ---- fig.dim = c(8, 6), echo = FALSE-----------------------------------------
# Choix d'un vecteur de couleurs alternatif aléatoire
testCol <- palette.colors(n=17, palette="Polychrome 36")
map3<-showLCZ(sf=redonOSM,wf="OSM",column="LCZ_PRIMARY",repr="alter",colors=testCol, useStandCol = FALSE)


## ---- fig.dim = c(8, 6), echo = FALSE-----------------------------------------

LCZlevels<-c(2, 3, 5, 6, 8, 9, 10, 101, 102, 104, 105, 107)
map4<-showLCZ(sf=redonOSM,wf="OSM",column="LCZ_PRIMARY",repr="alter", LCZlevels = LCZlevels,drop=FALSE)

## ---- fig.dim = c(8, 6), echo = FALSE-----------------------------------------
# Choix de couleurs prises au hasard

# Après une première représentation on constate qu'il n'y a que les typeLevels 2, 3, 5, 6, 8, 9, 101, 102, 104, 105, 107.
# Je spécifie un vecteur de couleur de taille 11 colors
LCZlevels<-c(2, 3, 5, 6, 8, 9, 101, 102, 104, 105, 107)
couleurs<-c("red","brown1","orange","coral","grey","darkgreen","chartreuse4","springgreen3",
            "darkolivegreen","black","#6d67fd")
map5<-showLCZ(sf=redonOSM,wf="OSM",column="LCZ_PRIMARY",repr="alter",drop=TRUE,LCZlevels=LCZlevels,colors=couleurs)


## ---- fig.dim = c(8, 6), echo = FALSE-----------------------------------------
redonOSMgrouped<-groupLCZ(redonOSM,column="LCZ_PRIMARY",
                           urban=c("1","2","3","4","5","6","7","8","9"),
                           industry="10",
                           vegetation=c("101","102","103","104"),
                           impervious="105",pervious="106",water="107",colors=c("red","black","green","grey","burlywood","blue"))
map6<-showLCZ(redonOSMgrouped, column="grouped",repr="alter",wf="OSM",
        LCZlevels = c("urban","industry","vegetation","impervious","pervious","water"),
        colors=c("red","black","green","grey","burlywood","blue"))


## ---- fig.dim = c(16,12 ), echo = FALSE---------------------------------------
comparaison<-compareLCZ(sf1=redonBDT,column1="LCZ_PRIMARY", wf1="BD TOPO v2.2",
                        sf2=redonOSM,column2="LCZ_PRIMARY",wf2="Open Street Map", ref=1,
                        repr="standard",exwrite=F,location="Redon",saveG="comparison")
dirPath<-paste0(system.file("extdata",package="lczexplore"),"/")


## ---- out.width = "680px"-----------------------------------------------------
path <- system.file('extdata/RedonCompare.png',package="lczexplore")
knitr::include_graphics(path, error=FALSE)


## -----------------------------------------------------------------------------
comparaison$percAgg
comparaison$pseudoK

## -----------------------------------------------------------------------------
dirPath<-paste0(system.file("extdata",package="lczexplore"),"/")
dirPathOSM<-paste0(dirPath,"osm/2022/Redon")
dirPathBDT<-paste0(dirPath,"bdtopo_2_2/Redon")
## La fonction d'import fonctionne en réalité aussi avec les fichiers shape
## Notez que les noms des colonnes sont différents pour le fichier shape, dans tous les cas
## c'est le nom des colonnes de votre fichier que vous rentrerez.
redonBDT<-importLCZvect(dirPath=dirPathBDT,file="rsu_lcz_bdt_redon.shp",
                       column ="LCZ_PRIMAR",geomID = "ID_RSU",confid="LCZ_UNIQUE" )

redonOSM<-importLCZvect(dirPath=dirPathOSM,file="rsu_lcz.geojson",column = "LCZ_PRIMARY",geomID = "ID_RSU",confid="LCZ_UNIQUENESS_VALUE")
# Afin de conserver les mêmes noms, on réimporte avec le geojson
redonBDT<-importLCZvect(dirPath=dirPathBDT,file="rsu_lcz.geojson",column = "LCZ_PRIMARY",geomID = "ID_RSU",confid="LCZ_UNIQUENESS_VALUE")


## ---- echo = TRUE, fig.show="hide"--------------------------------------------
redonCompare<-compareLCZ(sf1=redonBDT,wf1="bdt", geomID1 = "ID_RSU",column1 ="LCZ_PRIMARY",
                         confid1 = "LCZ_UNIQUENESS_VALUE",
                         sf2=redonOSM,wf2="osm",geomID2 = "ID_RSU",column2="LCZ_PRIMARY",confid2 ="LCZ_UNIQUENESS_VALUE",exwrite=FALSE, saveG="comparaison")
# redonInputSensib<-read.csv()

## ---- out.width = "680px"-----------------------------------------------------

knitr::include_graphics("comparaison.png", error=FALSE)


## ---- fig.dim = c(12,9), fig.show="hide"--------------------------------------
names(redonCompare$data)
confidRedon<-confidSensib(inputDf=redonCompare$data,filePath="", nPoints=10,
             wf1="bdtopo_2_2", wf2="osm",
             geomID1="ID_RSU", column1="LCZ_PRIMARY", confid1="LCZ_UNIQUENESS_VALUE",
             geomID2="ID_RSU.1",column2="LCZ_PRIMARY.1", confid2="LCZ_UNIQUENESS_VALUE.1",
             sep=";", repr="standard",
             plot=TRUE, saveG = ".")


## ---- out.width = "680px"-----------------------------------------------------

knitr::include_graphics("GeneralUniquenessSensib.png", error=FALSE)


## ---- out.width = "680px"-----------------------------------------------------

knitr::include_graphics("byLCZUniquenessSensib.png", error=FALSE)


