## ---- include = FALSE---------------------------------------------------------
knitr::opts_chunk$set(
        collapse = TRUE,
        comment = "#>"
)
if (!require("png")) {
  install.packages("png",repos = "http://cran.us.r-project.org")
  library("png")
}


## -----------------------------------------------------------------------------
library(lczexplore)

## -----------------------------------------------------------------------------
redonBbox<-importLCZvect(dirPath=paste0(system.file("extdata", package = "lczexplore"),
"/bdtopo_2_2/Redon"), file="rsu_lcz.geojson",column="LCZ_PRIMARY",output="bBox")


# Example with osmdata function getbb, not run, to avoid installation of the package
# library(osmdata)
# redonBbox<-getbb("Redon", format_out = "sf_polygon")

## -----------------------------------------------------------------------------
redonWudapt<-importLCZraster(system.file("extdata", package = "lczexplore"),
fileName="redonWudapt.tif", bBox=redonBbox)


## ---- echo=FALSE--------------------------------------------------------------
library(sf)
st_crs(redonWudapt)

## ---- fig.dim = c(8, 6)-------------------------------------------------------
summary(redonWudapt)
summary(redonWudapt$EU_LCZ_map)

## ---- fig.dim = c(8, 6)-------------------------------------------------------
map1<-showLCZ(sf = redonWudapt,column = 'EU_LCZ_map', repr= "standard")

## -----------------------------------------------------------------------------
# Path to embedded Data
dirPath<-paste0(system.file("extdata",package="lczexplore"),"/")
# Path to OSM data specifically
dirPathOSM<-paste0(dirPath,"osm/2022/Redon")
# loading Redon Data produced with GeoClimate on OSM input Data
redonOSM<-importLCZvect(dirPath=dirPathOSM,file="rsu_lcz.geojson",column = "LCZ_PRIMARY", drop=TRUE)
summary(redonOSM$LCZ_PRIMARY)


## ---- fig.dim = c(8, 6), echo = TRUE------------------------------------------
map2<-showLCZ(sf = redonOSM, repr="standard")


## ----  echo = TRUE, fig.show="hide"-------------------------------------------
summary(redonOSM)
summary(redonWudapt)
compareLCZ(sf1 = redonWudapt, column1 = "EU_LCZ_map", wf1="WUDAPT",
           sf2 = redonOSM, column2 = "LCZ_PRIMARY", wf2 = "GeoClimate_OSM",
           ref=1 ,exwrite=FALSE,saveG = "comparisonR" )

## ---- out.width = "680px"-----------------------------------------------------

knitr::include_graphics("comparisonR.png", error=FALSE)


## ---- echo=TRUE, , fig.show="hide"--------------------------------------------

# Regroup levels of the WUDAPT sf file.
redonWudaptGrouped<-groupLCZ(redonWudapt,column="EU_LCZ_map",
                              urban=c("1","2","3","4","5","6","7","8","9"),
                              industry="10", vegetation=c("101","102","103","104"),
                              impervious="105",pervious="106",water="107", outCol = "Regrouped")

# Regroup levels of the GeoClimate sf file
redonOSMgrouped<-groupLCZ(redonOSM, column="LCZ_PRIMARY",
urban=c("1","2","3","4","5","6","7","8","9"),
industry="10", vegetation=c("101","102","103","104"),
impervious="105",pervious="106",water="107", outCol = "Regrouped")


# Pass the files, the columsn and a vector of colors associated to the broader categories

compareLCZ(sf1 = redonWudaptGrouped, column1 = "Regrouped", wf1 = "Wudapt",
           sf2 = redonOSMgrouped, column2 = "Regrouped", wf2 = " GeoClimate on OSM data",
           exwrite = FALSE, plot=TRUE, repr="alter", levels=c("urban","industry","vegetation","impervious","pervious","water"),colors=c("red","black","green","grey","burlywood","blue"), saveG="comparisonGroupedR")



## ---- out.width = "680px"-----------------------------------------------------

knitr::include_graphics("comparisonGroupedR.png", error=FALSE)


## ---- echo=TRUE, fig.show="hide"----------------------------------------------
# Dedicated files were integrated to demonstrate the whole workflow on an area of Sidney

# importation of LCZ map prduced using GeoClimate with OpenStreetMap data
sidneyOSM<-importLCZvect(
dirPath = system.file("extdata/osm/2022/Sidney", package = "lczexplore"), file="sidney_rsu_lcz.geojson",
column="LCZ_PRIMARY",
confid="LCZ_UNIQUENESS_VALUE",
geomID="ID_RSU")

# Creation of the bounding box of this area to crop the raster file produced using the WUDAPT platform
sidneyBbox<-importLCZvect(
system.file("extdata/osm/2022/Sidney", package = "lczexplore"), file="sidney_rsu_lcz.geojson",
,output = "bBox")

# Import of the raster filed, cropped to the bounbding box of the area of interest. 
sidneyWudapt<-importLCZraster(system.file("extdata", package = "lczexplore"),
fileName="rasterMD.tif", LCZband=1,  LCZcolumn = "LCZraster",
                              confidenceBand = 3, confidenceColumn = "confidence",
                              bBox = sidneyBbox )
# Make raster confidence value between 0 and 1  

sidneyWudapt$confidence<-sidneyWudapt$confidence/100

sidneyComparison<-compareLCZ(
  sf1=sidneyOSM, geomID1="ID_RSU", column1="LCZ_PRIMARY", wf1="BD TOPO v2.2", confid1 = "LCZ_UNIQUENESS_VALUE",
  sf2=sidneyWudapt, geomID2="geomID", column2="LCZraster", wf2="Open Street Map", confid2="confidence",
  ref=1,repr="standard",exwrite=F, location="Part of Sidney")

confidSidney<-confidSensib(inputDf=sidneyComparison$data, nPoints=5,
                          wf1="GC on OSM", wf2="WUDAPT",
                          geomID1="ID_RSU", column1="LCZ_PRIMARY", confid1="LCZ_UNIQUENESS_VALUE",
                          geomID2="geomID",column2="LCZraster", confid2="confidence",
                          sep=";", repr="standard",
                          plot=TRUE, saveG = ".")


## ---- out.width = "680px"-----------------------------------------------------

knitr::include_graphics("GeneralUniquenessSensib.png", error=FALSE)


## ---- out.width = "680px"-----------------------------------------------------

knitr::include_graphics("byLCZUniquenessSensib.png", error=FALSE)


