% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/confidSensib.R
\name{confidSensib}
\alias{confidSensib}
\title{Computes the agreement between geographical (LCZ) classifications on a range of values of
an indicator of confidence granted to each LCZ classification.
The input file or dataset must have been produced by compareLCZ function,
or at least the columns must be in the same order.}
\usage{
confidSensib(
  inputDf = "",
  filePath = "",
  nPoints = 5,
  wf1 = "bdtopo_2_2",
  wf2 = "osm",
  geomID1 = "ID_RSU",
  column1 = "LCZ_PRIMARY",
  confid1 = "LCZ_UNIQUENESS_VALUE",
  geomID2 = "ID_RSU.1",
  column2 = "LCZ_PRIMARY.1",
  confid2 = "LCZ_UNIQUENESS_VALUE.1",
  sep = ";",
  repr = "standard",
  plot = TRUE,
  saveG = ""
)
}
\arguments{
\item{inputDf}{is an R file with geom IDs, (LCZ) classifications and
a confidence value granted for the (LCZ) classifications values of each geom. Ignored if filePath is not empty.}

\item{filePath}{is the path to a csv file containing geom IDs, LCZ classifications and
a confidence value granted for the LCZ value of each geom. Set it to "" if inputDf is specified (recommanded)}

\item{nPoints}{is the number of points (quantiles) of confidence for which
the average agreement between classifications will be computed}

\item{wf1}{is the name of the workflow used to produce the first LCZ}

\item{wf2}{is the name of the workflow used to produce the second LCZ}

\item{geomID1}{is the name of the column that contains the geom ID associated to the first workflow}

\item{column1}{is the name of the column storing the first LCZ classification values}

\item{confid1}{is the name of the column storing the first LCZ classification confidence value}

\item{geomID2}{is the name of the column that contains the geom ID associated to the second workflow}

\item{column2}{is the name of the column storing the second LCZ classification values}

\item{confid2}{is the name of the column storing the second LCZ classification confidence value}

\item{sep}{the separator used if filePath is not empty}

\item{repr}{is standard when original LCZ values are expected, alter otherwise}

\item{plot}{if TRUE the graph is plotted}

\item{saveG}{if not an empty string, specifies where to save graphs}
}
\value{
returns an object called output, which contains the values of the thresholds
for the confidence value and the agreement between classifications for the LCZ levels presents in the dataset
}
\description{
Computes the agreement between geographical (LCZ) classifications on a range of values of
an indicator of confidence granted to each LCZ classification.
The input file or dataset must have been produced by compareLCZ function,
or at least the columns must be in the same order.
}
\examples{
# creation of the comparison data on which to perform the analysis
redonCompare<-compareLCZ(sf1=redonBDT, wf1="bdt", geomID1 = "ID_RSU", column1 ="LCZ_PRIMARY",
                        confid1 = "LCZ_UNIQUENESS_VALUE",
                        sf2=redonOSM, wf2="osm",geomID2 = "ID_RSU", column2="LCZ_PRIMARY",
                        confid2 ="LCZ_UNIQUENESS_VALUE", exwrite=FALSE, plot=FALSE, saveG="")
confidSensib(inputDf=redonCompare$data,
nPoints=5, wf1="bdtopo_2_2", wf2="osm",
geomID1="ID_RSU", column1="LCZ_PRIMARY", confid1="LCZ_UNIQUENESS_VALUE",
geomID2="ID_RSU.1",column2="LCZ_PRIMARY.1", confid2="LCZ_UNIQUENESS_VALUE.1",
sep=";", repr="standard", plot=TRUE, saveG="")
}
