% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/importLCZraster.R
\name{importLCZraster}
\alias{importLCZraster}
\title{Imports the LCZ classifications produced on raster maps.
For now, the european tif map produced by WUDAP is used as a reference example.
Users can DOWNLOAD the WUDAPT tif file at the following url :
https://figshare.com/articles/dataset/European_LCZ_map/13322450}
\usage{
importLCZraster(
  dirPath,
  bBox,
  fileName = "EU_LCZ_map.tif",
  LCZband = 1,
  LCZcolumn = "EU_LCZ_map",
  confidenceBand = "",
  confidenceColumn = "confidence",
  typeLevels = c(`1` = "1", `2` = "2", `3` = "3", `4` = "4", `5` = "5", `6` = "6", `7` =
    "7", `8` = "8", `9` = "9", `10` = "10", `101` = "11", `102` = "12", `103` = "13",
    `104` = "14", `105` = "15", `106` = "16", `107` = "17")
)
}
\arguments{
\item{dirPath}{is the path to the directory where the}

\item{bBox}{bBox is the bounding box needed to crop the raster file.
It can be produced bu the importLCZvect function. It can either be of class bBox or of class sfc}

\item{fileName}{is the name of the raster file (tif or geotif), by default \'EU_LCZ_map.tif\'.}

\item{LCZband}{defines the band of the raster file which contains the LCZ types.
It can be a number or a band name (default = 1)}

\item{LCZcolumn}{the name of the column of the output sf File in which the LCZ types will be stored
(default = "LCZ")}

\item{confidenceBand}{the band of the raster files which contains a measure of confidence.
Can be a number or a band name (default = "", that is no measure of confidence provided)}

\item{confidenceColumn}{the name of the column of the output sf File in which the confidence values will be stored
(default = "", no confidence value specified)}

\item{typeLevels}{indicates a named vector of the unique values contained in LCZcolumn,}
}
\value{
an sf file containing the geom and LCZ levels from theraster tiff within the bBox bounding box
}
\description{
Imports the LCZ classifications produced on raster maps.
For now, the european tif map produced by WUDAP is used as a reference example.
Users can DOWNLOAD the WUDAPT tif file at the following url :
https://figshare.com/articles/dataset/European_LCZ_map/13322450
}
\examples{
redonBbox<-importLCZvect(dirPath=paste0(system.file("extdata", package = "lczexplore"),
"/bdtopo_2_2/Redon"), file="rsu_lcz.geojson", column="LCZ_PRIMARY", output="bBox")

redonWudapt<-importLCZraster(system.file("extdata", package = "lczexplore"),
fileName="redonWudapt.tif",bBox=redonBbox)

# another way to get the bounding box when one explores a given city would be the use of the 
# getbb() function from the osmdata package. 
# This exaample requires the osmdata package and therefore is not executed here
# redonBbox<-osmdata::getbb("Redon")
# redonWudapt<-importLCZraster(system.file("extdata", package = "lczexplore"),
# fileName="redonWudapt.tif",bBox=redonBbox)

# another way to get the bounding box when one doesn't want 
#to compare to a vector map is to enter it's coordinates 
# and feed them to st_bbox() of the sf package.

# imporLCZraster also allows to choose which band of a raster file to import
redonWudapt<-importLCZraster(system.file("extdata", package = "lczexplore"),
fileName="redonWudapt.tif",bBox=redonBbox, LCZband=1, LCZcolumn='EU_LCZ_map')
}
