% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/produceAnalysis.R
\name{produceAnalysis}
\alias{produceAnalysis}
\title{Calls functions of the package to produce an analysis of two set of LCZ
produced exclusively by GeoClimate.
Typically one will compare the LCZ produced by GeoClimate using the OpenStreetMap
data as input to
the LCZ produced by GeoClimate using the french BDTopo v2.2 as input.
Same analysis are reproducible using all the generic functions of the package.}
\usage{
produceAnalysis(
  location = "Redon",
  outDir = getwd(),
  wf1 = "bdtopo_2_2",
  wf2 = "osm",
  refYear1 = "2022",
  refYear2 = "2022",
  repr = "standard",
  saveG = location,
  ...
)
}
\arguments{
\item{location}{defines the study area. The study area must have been coputed
and loaded on the cloud of the team. If the fetch function returns an error,
please contact the GeoClimate Team to make the data available}

\item{outDir}{is the directory in which the output will be saved,
namely the graphics and both LCZ for intersected geometries}

\item{wf1}{is the name of the workflow GeoClimate used to produce the first dataset It can be "osm" or "bdtopo_2_2"}

\item{wf2}{is the name of the workflow Geoclimate used to produce the second dataset It can be "osm" or "bdtopo_2_2"
If needed, future versions may allow other values}

\item{refYear1}{allows to indicate on which year the analysis was produced.
It is important for "osm" workflow as the data are updated frequently.}

\item{refYear2}{see refYear1.}

\item{repr}{: "standard" means that original values of LCZ are used, "alter" means the user wishes to group some of the LCZ levels under a new label.}

\item{saveG}{: when an empty character string, "", the plots are not saved. Else, the saveG string is used to produce the name of the saved png file.}

\item{...}{allow to pass arguments if representation is alter.
The expected arguments are the name of each grouped label,
the levels of LCZ they contain, and last a vector of the colors to use to plot them.}
}
\value{
: the function doesn't return an object, as all the results
are exported either in csv (both LCZ by geoms by town) either in png
(maps of LCZ classifications and agreement, and confusion matrix).
}
\description{
Calls functions of the package to produce an analysis of two set of LCZ
produced exclusively by GeoClimate.
Typically one will compare the LCZ produced by GeoClimate using the OpenStreetMap
data as input to
the LCZ produced by GeoClimate using the french BDTopo v2.2 as input.
Same analysis are reproducible using all the generic functions of the package.
}
\examples{
produceAnalysis(location="Redon", outDir=paste0(system.file(package="lczexplore"),"/tinytest"),
wf1="bdtopo_2_2", wf2="osm", refYear1="2022", refYear2="2022", repr="standard", saveG="")
}
