% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/showLCZ.R
\name{showLCZ}
\alias{showLCZ}
\title{Produces a simple representation of the LCZ contained in an sf file.}
\usage{
showLCZ(
  sf,
  title = "",
  wf = "",
  column = "LCZ_PRIMARY",
  repr = "standard",
  drop = FALSE,
  useStandCol = FALSE,
  tryGroup = TRUE,
  ...
)
}
\arguments{
\item{sf}{is the sf file which contains the LCZ column to be plotted.}

\item{title}{allows the user to set the title of the plot}

\item{wf}{is the workflow used to produced the LCZ. "bdt" and "osm" indicate
that LCZ were produced by GeoClimate using the BD_TOPO_V2 or the Open Street Map data as input, respectively.
If the LCZ were produced by WUDAPT, use "wudapt".}

\item{column}{is the column that contains the LCZ.}

\item{repr}{indicates if the sf dataset contains standarde LCZ levels or grouped LCZ.
If "standard" then an optimal set of colors is used to produce the plotted map. Else, colors can be specified with the colors argument.}

\item{drop}{indicates if you want to show the levels present in no geometry.}

\item{useStandCol}{is set to TRUE implies that any levels detected as a standard LCZ level will receive the standard associated color}

\item{tryGroup}{is set to TRUE when one wants to group and plot on the fly}

\item{...}{these dynamic dots allow you to pass arguments to specify levels expected
in your dataset and colors associated to these levels when not in the standard representation. You can pas your levels through a vector and you colors through another vector called colors.
For more details about this, read the "lcz_explore_alter" vignette.}
}
\value{
return the plot of the LCZ levels
}
\description{
Produces a simple representation of the LCZ contained in an sf file.
}
\examples{
# On original LCZ levels, use the \'standard\' value for the \'repr\' argument.
showLCZ(redonBDT, column="LCZ_PRIMARY", repr="standard")
# On grouped data, use the alter value for the repr argument.
redonBDTgrouped<-groupLCZ(redonBDT,column="LCZ_PRIMARY",
urban=c("1","2","3","4","5","6","7","8","9"),
industry="10", vegetation=c("101","102","103","104"),
impervious="105",pervious="106",water="107")
# For repr="alter", you can specify colors and levels this way :
showLCZ(redonBDTgrouped,column="grouped",repr="alter",
LCZlevels=c("urban","industry","vegetation","impervious","pervious","water"),
colors=c("red","black","green","grey","burlywood","blue"),wf="BD TOPO")

}
